@@ -25,6 +25,7 @@
  */
 
 #include "header/client.h"
+#include "../backends/generic/header/input.h"
 
 void CL_DownloadFileName(char *dest, int destlen, char *fn);
 void CL_ParseDownload(void);
@@ -73,7 +74,7 @@ CL_RegisterSounds(void)
 		}
 
 		cl.sound_precache[i] = S_RegisterSound(cl.configstrings[CS_SOUNDS + i]);
-		Sys_SendKeyEvents();
+		IN_Update();
 	}
 
 	S_EndRegistration();
@@ -1082,24 +1083,14 @@ CL_ParseConfigString(void)
 	{
 		if (cl.refresh_prepped)
 		{
+			int track = (int)strtol(cl.configstrings[CS_CDTRACK], (char **)NULL, 10);
 #ifdef CDA
-			CDAudio_Play((int)strtol(cl.configstrings[CS_CDTRACK],
-							(char **)NULL, 10), true);
+			CDAudio_Play(track, true);
 #endif
 
 #ifdef OGG
 
-			/* OGG/Vorbis */
-			if ((int)strtol(cl.configstrings[CS_CDTRACK], (char **)NULL, 10) < 10)
-			{
-				char tmp[3] = "0";
-				OGG_ParseCmd(strcat(tmp, cl.configstrings[CS_CDTRACK]));
-			}
-			else
-			{
-				OGG_ParseCmd(cl.configstrings[CS_CDTRACK]);
-			}
-
+			OGG_PlayTrack(track);
 #endif
 		}
 	}
