@@ -63,9 +63,6 @@ vec3_t vpn;
 vec3_t vright;
 vec3_t gl3_origin;
 
-hmm_mat4 gl3_projectionMatrix; // eye cord -> clip coord
-hmm_mat4 gl3_world_matrix; // the view matrix: world coord -> eye coord
-
 int gl3_visframecount; /* bumped when going to a new PVS */
 int gl3_framecount; /* used for dlight push checking */
 
@@ -83,49 +80,46 @@ const hmm_mat4 gl3_identityMat4 = {{
 }};
 
 cvar_t *gl_msaa_samples;
-cvar_t *gl_swapinterval;
+cvar_t *r_vsync;
 cvar_t *gl_retexturing;
 cvar_t *vid_fullscreen;
-cvar_t *gl_mode;
-cvar_t *gl_customwidth;
-cvar_t *gl_customheight;
+cvar_t *r_mode;
+cvar_t *r_customwidth;
+cvar_t *r_customheight;
 cvar_t *vid_gamma;
 cvar_t *gl_anisotropic;
 cvar_t *gl_texturemode;
 cvar_t *gl_drawbuffer;
-cvar_t *gl_clear;
+cvar_t *r_clear;
 cvar_t *gl3_particle_size;
 cvar_t *gl3_particle_fade_factor;
 cvar_t *gl3_particle_square;
 
 cvar_t *gl_lefthand;
-cvar_t *gl_farsee;
+cvar_t *r_gunfov;
+cvar_t *r_farsee;
 
 cvar_t *gl3_intensity;
 cvar_t *gl3_intensity_2D;
-cvar_t *gl_lightlevel;
+cvar_t *r_lightlevel;
 cvar_t *gl3_overbrightbits;
 
-cvar_t *gl_norefresh;
-cvar_t *gl_drawentities;
-cvar_t *gl_drawworld;
+cvar_t *r_norefresh;
+cvar_t *r_drawentities;
+cvar_t *r_drawworld;
 cvar_t *gl_nolerp_list;
 cvar_t *gl_nobind;
-cvar_t *gl_lockpvs;
-cvar_t *gl_novis;
-cvar_t *gl_speeds;
+cvar_t *r_lockpvs;
+cvar_t *r_novis;
+cvar_t *r_speeds;
 cvar_t *gl_finish;
 
 cvar_t *gl_cull;
 cvar_t *gl_zfix;
-cvar_t *gl_fullbright;
-cvar_t *gl_modulate;
+cvar_t *r_fullbright;
+cvar_t *r_modulate;
 cvar_t *gl_lightmap;
 cvar_t *gl_shadows;
-// no gl_stencilshadows, always use stencil (if available)
-
-cvar_t *gl_dynamic;
-
 cvar_t *gl3_debugcontext;
 
 // Yaw-Pitch-Roll
@@ -197,24 +191,25 @@ static void
 GL3_Register(void)
 {
 	gl_lefthand = ri.Cvar_Get("hand", "0", CVAR_USERINFO | CVAR_ARCHIVE);
-	gl_farsee = ri.Cvar_Get("gl_farsee", "0", CVAR_LATCH | CVAR_ARCHIVE);
+	r_gunfov = ri.Cvar_Get("r_gunfov", "80", CVAR_ARCHIVE);
+	r_farsee = ri.Cvar_Get("r_farsee", "0", CVAR_LATCH | CVAR_ARCHIVE);
 
 	gl_drawbuffer = ri.Cvar_Get("gl_drawbuffer", "GL_BACK", 0);
-	gl_swapinterval = ri.Cvar_Get("gl_swapinterval", "1", CVAR_ARCHIVE);
+	r_vsync = ri.Cvar_Get("r_vsync", "1", CVAR_ARCHIVE);
 	gl_msaa_samples = ri.Cvar_Get ( "gl_msaa_samples", "0", CVAR_ARCHIVE );
 	gl_retexturing = ri.Cvar_Get("gl_retexturing", "1", CVAR_ARCHIVE);
 	gl3_debugcontext = ri.Cvar_Get("gl3_debugcontext", "0", 0);
-	gl_mode = ri.Cvar_Get("gl_mode", "4", CVAR_ARCHIVE);
-	gl_customwidth = ri.Cvar_Get("gl_customwidth", "1024", CVAR_ARCHIVE);
-	gl_customheight = ri.Cvar_Get("gl_customheight", "768", CVAR_ARCHIVE);
+	r_mode = ri.Cvar_Get("r_mode", "4", CVAR_ARCHIVE);
+	r_customwidth = ri.Cvar_Get("r_customwidth", "1024", CVAR_ARCHIVE);
+	r_customheight = ri.Cvar_Get("r_customheight", "768", CVAR_ARCHIVE);
 	gl3_particle_size = ri.Cvar_Get("gl3_particle_size", "40", CVAR_ARCHIVE);
 	gl3_particle_fade_factor = ri.Cvar_Get("gl3_particle_fade_factor", "1.2", CVAR_ARCHIVE);
 	gl3_particle_square = ri.Cvar_Get("gl3_particle_square", "0", CVAR_ARCHIVE);
 
-	gl_norefresh = ri.Cvar_Get("gl_norefresh", "0", 0);
-	gl_drawentities = ri.Cvar_Get("gl_drawentities", "1", 0);
-	gl_drawworld = ri.Cvar_Get("gl_drawworld", "1", 0);
-	gl_fullbright = ri.Cvar_Get("gl_fullbright", "0", 0);
+	r_norefresh = ri.Cvar_Get("r_norefresh", "0", 0);
+	r_drawentities = ri.Cvar_Get("r_drawentities", "1", 0);
+	r_drawworld = ri.Cvar_Get("r_drawworld", "1", 0);
+	r_fullbright = ri.Cvar_Get("r_fullbright", "0", 0);
 
 	/* don't bilerp characters and crosshairs */
 	gl_nolerp_list = ri.Cvar_Get("gl_nolerp_list", "pics/conchars.pcx pics/ch1.pcx pics/ch2.pcx pics/ch3.pcx", 0);
@@ -228,92 +223,83 @@ GL3_Register(void)
 	gl3_intensity = ri.Cvar_Get("gl3_intensity", "1.5", CVAR_ARCHIVE);
 	gl3_intensity_2D = ri.Cvar_Get("gl3_intensity_2D", "1.5", CVAR_ARCHIVE);
 
-	gl_lightlevel = ri.Cvar_Get("gl_lightlevel", "0", 0);
+	r_lightlevel = ri.Cvar_Get("r_lightlevel", "0", 0);
 	gl3_overbrightbits = ri.Cvar_Get("gl3_overbrightbits", "1.3", CVAR_ARCHIVE);
 
 	gl_lightmap = ri.Cvar_Get("gl_lightmap", "0", 0);
 	gl_shadows = ri.Cvar_Get("gl_shadows", "0", CVAR_ARCHIVE);
 
-	gl_modulate = ri.Cvar_Get("gl_modulate", "1", CVAR_ARCHIVE);
+	r_modulate = ri.Cvar_Get("r_modulate", "1", CVAR_ARCHIVE);
 	gl_zfix = ri.Cvar_Get("gl_zfix", "0", 0);
-	gl_clear = ri.Cvar_Get("gl_clear", "0", 0);
+	r_clear = ri.Cvar_Get("r_clear", "0", 0);
 	gl_cull = ri.Cvar_Get("gl_cull", "1", 0);
-	gl_lockpvs = ri.Cvar_Get("gl_lockpvs", "0", 0);
-	gl_novis = ri.Cvar_Get("gl_novis", "0", 0);
-	gl_speeds = ri.Cvar_Get("gl_speeds", "0", 0);
+	r_lockpvs = ri.Cvar_Get("r_lockpvs", "0", 0);
+	r_novis = ri.Cvar_Get("r_novis", "0", 0);
+	r_speeds = ri.Cvar_Get("r_speeds", "0", 0);
 	gl_finish = ri.Cvar_Get("gl_finish", "0", CVAR_ARCHIVE);
 
-	gl_dynamic = ri.Cvar_Get("gl_dynamic", "1", 0);
-
-
 #if 0 // TODO!
 	//gl_lefthand = ri.Cvar_Get("hand", "0", CVAR_USERINFO | CVAR_ARCHIVE);
 	//gl_farsee = ri.Cvar_Get("gl_farsee", "0", CVAR_LATCH | CVAR_ARCHIVE);
-	//gl_norefresh = ri.Cvar_Get("gl_norefresh", "0", 0);
-	//gl_fullbright = ri.Cvar_Get("gl_fullbright", "0", 0);
-	//gl_drawentities = ri.Cvar_Get("gl_drawentities", "1", 0);
-	//gl_drawworld = ri.Cvar_Get("gl_drawworld", "1", 0);
-	//gl_novis = ri.Cvar_Get("gl_novis", "0", 0);
-	//gl_lerpmodels = ri.Cvar_Get("gl_lerpmodels", "1", 0); NOTE: screw this, it looks horrible without
-	//gl_speeds = ri.Cvar_Get("gl_speeds", "0", 0);
+	//r_norefresh = ri.Cvar_Get("r_norefresh", "0", 0);
+	//r_fullbright = ri.Cvar_Get("r_fullbright", "0", 0);
+	//r_drawentities = ri.Cvar_Get("r_drawentities", "1", 0);
+	//r_drawworld = ri.Cvar_Get("r_drawworld", "1", 0);
+	//r_novis = ri.Cvar_Get("r_novis", "0", 0);
+	//r_lerpmodels = ri.Cvar_Get("r_lerpmodels", "1", 0); NOTE: screw this, it looks horrible without
+	//r_speeds = ri.Cvar_Get("r_speeds", "0", 0);
 
-	//gl_lightlevel = ri.Cvar_Get("gl_lightlevel", "0", 0);
+	//r_lightlevel = ri.Cvar_Get("r_lightlevel", "0", 0);
 	//gl_overbrightbits = ri.Cvar_Get("gl_overbrightbits", "0", CVAR_ARCHIVE);
 
-	gl_particle_min_size = ri.Cvar_Get("gl_particle_min_size", "2", CVAR_ARCHIVE);
-	gl_particle_max_size = ri.Cvar_Get("gl_particle_max_size", "40", CVAR_ARCHIVE);
-	//gl_particle_size = ri.Cvar_Get("gl_particle_size", "40", CVAR_ARCHIVE);
-	gl_particle_att_a = ri.Cvar_Get("gl_particle_att_a", "0.01", CVAR_ARCHIVE);
-	gl_particle_att_b = ri.Cvar_Get("gl_particle_att_b", "0.0", CVAR_ARCHIVE);
-	gl_particle_att_c = ri.Cvar_Get("gl_particle_att_c", "0.01", CVAR_ARCHIVE);
+	gl1_particle_min_size = ri.Cvar_Get("gl1_particle_min_size", "2", CVAR_ARCHIVE);
+	gl1_particle_max_size = ri.Cvar_Get("gl1_particle_max_size", "40", CVAR_ARCHIVE);
+	//gl1_particle_size = ri.Cvar_Get("gl1_particle_size", "40", CVAR_ARCHIVE);
+	gl1_particle_att_a = ri.Cvar_Get("gl1_particle_att_a", "0.01", CVAR_ARCHIVE);
+	gl1_particle_att_b = ri.Cvar_Get("gl1_particle_att_b", "0.0", CVAR_ARCHIVE);
+	gl1_particle_att_c = ri.Cvar_Get("gl1_particle_att_c", "0.01", CVAR_ARCHIVE);
 
 	//gl_modulate = ri.Cvar_Get("gl_modulate", "1", CVAR_ARCHIVE);
-	//gl_mode = ri.Cvar_Get("gl_mode", "4", CVAR_ARCHIVE);
+	//r_mode = ri.Cvar_Get("r_mode", "4", CVAR_ARCHIVE);
 	//gl_lightmap = ri.Cvar_Get("gl_lightmap", "0", 0);
 	//gl_shadows = ri.Cvar_Get("gl_shadows", "0", CVAR_ARCHIVE);
-	//gl_stencilshadow = ri.Cvar_Get("gl_stencilshadow", "0", CVAR_ARCHIVE);
-	//gl_dynamic = ri.Cvar_Get("gl_dynamic", "1", 0);
 	//gl_nobind = ri.Cvar_Get("gl_nobind", "0", 0);
-	gl_round_down = ri.Cvar_Get("gl_round_down", "1", 0);
-	gl_picmip = ri.Cvar_Get("gl_picmip", "0", 0);
 	gl_showtris = ri.Cvar_Get("gl_showtris", "0", 0);
 	gl_showbbox = Cvar_Get("gl_showbbox", "0", 0);
-	//gl_ztrick = ri.Cvar_Get("gl_ztrick", "0", 0); NOTE: dump this.
+	//gl1_ztrick = ri.Cvar_Get("gl1_ztrick", "0", 0); NOTE: dump this.
 	//gl_zfix = ri.Cvar_Get("gl_zfix", "0", 0);
 	//gl_finish = ri.Cvar_Get("gl_finish", "0", CVAR_ARCHIVE);
-	gl_clear = ri.Cvar_Get("gl_clear", "0", 0);
+	r_clear = ri.Cvar_Get("r_clear", "0", 0);
 //	gl_cull = ri.Cvar_Get("gl_cull", "1", 0);
-	gl_polyblend = ri.Cvar_Get("gl_polyblend", "1", 0);
-	//gl_flashblend = ri.Cvar_Get("gl_flashblend", "0", 0);
+	//gl1_flashblend = ri.Cvar_Get("gl1_flashblend", "0", 0);
 
 	//gl_texturemode = ri.Cvar_Get("gl_texturemode", "GL_LINEAR_MIPMAP_NEAREST", CVAR_ARCHIVE);
-	gl_texturealphamode = ri.Cvar_Get("gl_texturealphamode", "default", CVAR_ARCHIVE);
-	gl_texturesolidmode = ri.Cvar_Get("gl_texturesolidmode", "default", CVAR_ARCHIVE);
+	gl1_texturealphamode = ri.Cvar_Get("gl1_texturealphamode", "default", CVAR_ARCHIVE);
+	gl1_texturesolidmode = ri.Cvar_Get("gl1_texturesolidmode", "default", CVAR_ARCHIVE);
 	//gl_anisotropic = ri.Cvar_Get("gl_anisotropic", "0", CVAR_ARCHIVE);
-	//gl_lockpvs = ri.Cvar_Get("gl_lockpvs", "0", 0);
+	//r_lockpvs = ri.Cvar_Get("r_lockpvs", "0", 0);
 
-	//gl_palettedtexture = ri.Cvar_Get("gl_palettedtexture", "0", CVAR_ARCHIVE); NOPE.
-	gl_pointparameters = ri.Cvar_Get("gl_pointparameters", "1", CVAR_ARCHIVE);
+	//gl1_palettedtexture = ri.Cvar_Get("gl1_palettedtexture", "0", CVAR_ARCHIVE); NOPE.
+	gl1_pointparameters = ri.Cvar_Get("gl1_pointparameters", "1", CVAR_ARCHIVE);
 
 	//gl_drawbuffer = ri.Cvar_Get("gl_drawbuffer", "GL_BACK", 0);
-	//gl_swapinterval = ri.Cvar_Get("gl_swapinterval", "1", CVAR_ARCHIVE);
+	//r_vsync = ri.Cvar_Get("r_vsync", "1", CVAR_ARCHIVE);
 
-	gl_saturatelighting = ri.Cvar_Get("gl_saturatelighting", "0", 0);
 
 	//vid_fullscreen = ri.Cvar_Get("vid_fullscreen", "0", CVAR_ARCHIVE);
 	//vid_gamma = ri.Cvar_Get("vid_gamma", "1.0", CVAR_ARCHIVE);
 
-	//gl_customwidth = ri.Cvar_Get("gl_customwidth", "1024", CVAR_ARCHIVE);
-	//gl_customheight = ri.Cvar_Get("gl_customheight", "768", CVAR_ARCHIVE);
+	//r_customwidth = ri.Cvar_Get("r_customwidth", "1024", CVAR_ARCHIVE);
+	//r_customheight = ri.Cvar_Get("r_customheight", "768", CVAR_ARCHIVE);
 	//gl_msaa_samples = ri.Cvar_Get ( "gl_msaa_samples", "0", CVAR_ARCHIVE );
 
 	//gl_retexturing = ri.Cvar_Get("gl_retexturing", "1", CVAR_ARCHIVE);
 
 
-	gl_stereo = ri.Cvar_Get( "gl_stereo", "0", CVAR_ARCHIVE );
-	gl_stereo_separation = ri.Cvar_Get( "gl_stereo_separation", "-0.4", CVAR_ARCHIVE );
-	gl_stereo_anaglyph_colors = ri.Cvar_Get( "gl_stereo_anaglyph_colors", "rc", CVAR_ARCHIVE );
-	gl_stereo_convergence = ri.Cvar_Get( "gl_stereo_convergence", "1", CVAR_ARCHIVE );
+	gl1_stereo = ri.Cvar_Get( "gl1_stereo", "0", CVAR_ARCHIVE );
+	gl1_stereo_separation = ri.Cvar_Get( "gl1_stereo_separation", "-0.4", CVAR_ARCHIVE );
+	gl1_stereo_anaglyph_colors = ri.Cvar_Get( "gl1_stereo_anaglyph_colors", "rc", CVAR_ARCHIVE );
+	gl1_stereo_convergence = ri.Cvar_Get( "gl1_stereo_convergence", "1", CVAR_ARCHIVE );
 #endif // 0
 
 	ri.Cmd_AddCommand("imagelist", GL3_ImageList_f);
@@ -370,23 +356,23 @@ GL3_SetMode(void)
 	fullscreen = (int)vid_fullscreen->value;
 
 	vid_fullscreen->modified = false;
-	gl_mode->modified = false;
+	r_mode->modified = false;
 
 	/* a bit hackish approach to enable custom resolutions:
 	   Glimp_SetMode needs these values set for mode -1 */
-	vid.width = gl_customwidth->value;
-	vid.height = gl_customheight->value;
+	vid.width = r_customwidth->value;
+	vid.height = r_customheight->value;
 
-	if ((err = SetMode_impl(&vid.width, &vid.height, gl_mode->value,
+	if ((err = SetMode_impl(&vid.width, &vid.height, r_mode->value,
 					 fullscreen)) == rserr_ok)
 	{
-		if (gl_mode->value == -1)
+		if (r_mode->value == -1)
 		{
 			gl3state.prev_mode = 4; /* safe default for custom mode */
 		}
 		else
 		{
-			gl3state.prev_mode = gl_mode->value;
+			gl3state.prev_mode = r_mode->value;
 		}
 	}
 	else
@@ -397,7 +383,7 @@ GL3_SetMode(void)
 			vid_fullscreen->modified = false;
 			R_Printf(PRINT_ALL, "ref_gl3::GL3_SetMode() - fullscreen unavailable in this mode\n");
 
-			if ((err = SetMode_impl(&vid.width, &vid.height, gl_mode->value, 0)) == rserr_ok)
+			if ((err = SetMode_impl(&vid.width, &vid.height, r_mode->value, 0)) == rserr_ok)
 			{
 				return true;
 			}
@@ -412,20 +398,20 @@ GL3_SetMode(void)
 				ri.Cvar_SetValue("gl_msaa_samples", 0.0f);
 				gl_msaa_samples->modified = false;
 
-				if ((err = SetMode_impl(&vid.width, &vid.height, gl_mode->value, 0)) == rserr_ok)
+				if ((err = SetMode_impl(&vid.width, &vid.height, r_mode->value, 0)) == rserr_ok)
 				{
 					return true;
 				}
 			}
-			if(gl_mode->value == gl3state.prev_mode)
+			if(r_mode->value == gl3state.prev_mode)
 			{
 				// trying again would result in a crash anyway, give up already
 				// (this would happen if your initing fails at all and your resolution already was 640x480)
 				return false;
 			}
 
-			ri.Cvar_SetValue("gl_mode", gl3state.prev_mode);
-			gl_mode->modified = false;
+			ri.Cvar_SetValue("r_mode", gl3state.prev_mode);
+			r_mode->modified = false;
 		}
 
 		/* try setting it back to something safe */
@@ -477,7 +463,7 @@ GL3_Init(void)
 
 	/* set our "safe" mode */
 	gl3state.prev_mode = 4;
-	//gl_state.stereo_mode = gl_stereo->value;
+	//gl_state.stereo_mode = gl1_stereo->value;
 
 	/* create the window and set up the context */
 	if (!GL3_SetMode())
@@ -892,7 +878,7 @@ GL3_DrawEntitiesOnList(void)
 {
 	int i;
 
-	if (!gl_drawentities->value)
+	if (!r_drawentities->value)
 	{
 		return;
 	}
@@ -1177,7 +1163,7 @@ static hmm_mat4 rotAroundAxisXYZ(float aroundXdeg, float aroundYdeg, float aroun
 }
 
 // equivalent to R_MYgluPerspective() but returning a matrix instead of setting internal OpenGL state
-static hmm_mat4
+hmm_mat4
 GL3_MYgluPerspective(GLdouble fovy, GLdouble aspect, GLdouble zNear, GLdouble zFar)
 {
 	// calculation of left, right, bottom, top is from R_MYgluPerspective() of old gl backend
@@ -1193,8 +1179,8 @@ GL3_MYgluPerspective(GLdouble fovy, GLdouble aspect, GLdouble zNear, GLdouble zF
 	right = top * aspect;
 
 	// TODO:  stereo stuff
-	// left += - gl_stereo_convergence->value * (2 * gl_state.camera_separation) / zNear;
-	// right += - gl_stereo_convergence->value * (2 * gl_state.camera_separation) / zNear;
+	// left += - gl1_stereo_convergence->value * (2 * gl_state.camera_separation) / zNear;
+	// right += - gl1_stereo_convergence->value * (2 * gl_state.camera_separation) / zNear;
 
 	// the following emulates glFrustum(left, right, bottom, top, zNear, zFar)
 	// see https://www.khronos.org/registry/OpenGL-Refpages/gl2.1/xhtml/glFrustum.xml
@@ -1248,8 +1234,8 @@ SetupGL(void)
 	/* set up projection matrix (eye coordinates -> clip coordinates) */
 	{
 		float screenaspect = (float)gl3_newrefdef.width / gl3_newrefdef.height;
-		float dist = (gl_farsee->value == 0) ? 4096.0f : 8192.0f;
-		gl3_projectionMatrix = GL3_MYgluPerspective(gl3_newrefdef.fov_y, screenaspect, 4, dist);
+		float dist = (r_farsee->value == 0) ? 4096.0f : 8192.0f;
+		gl3state.uni3DData.transProjMat4 = GL3_MYgluPerspective(gl3_newrefdef.fov_y, screenaspect, 4, dist);
 	}
 
 	glCullFace(GL_FRONT);
@@ -1273,11 +1259,9 @@ SetupGL(void)
 		hmm_vec3 trans = HMM_Vec3(-gl3_newrefdef.vieworg[0], -gl3_newrefdef.vieworg[1], -gl3_newrefdef.vieworg[2]);
 		viewMat = HMM_MultiplyMat4( viewMat, HMM_Translate(trans) );
 
-		gl3_world_matrix = viewMat;
+		gl3state.uni3DData.transViewMat4 = viewMat;
 	}
 
-	gl3state.uni3DData.transProjMat4 = gl3_projectionMatrix;
-	gl3state.uni3DData.transViewMat4 = gl3_world_matrix;
 	gl3state.uni3DData.transModelMat4 = gl3_identityMat4;
 
 	gl3state.uni3DData.time = gl3_newrefdef.time;
@@ -1316,12 +1300,12 @@ GL3_RenderView(refdef_t *fd)
 					// Work out the colour for each eye.
 					int anaglyph_colours[] = { 0x4, 0x3 }; // Left = red, right = cyan.
 
-					if (strlen(gl_stereo_anaglyph_colors->string) == 2) {
+					if (strlen(gl1_stereo_anaglyph_colors->string) == 2) {
 						int eye, colour, missing_bits;
 						// Decode the colour name from its character.
 						for (eye = 0; eye < 2; ++eye) {
 							colour = 0;
-							switch (toupper(gl_stereo_anaglyph_colors->string[eye])) {
+							switch (toupper(gl1_stereo_anaglyph_colors->string[eye])) {
 								case 'B': ++colour; // 001 Blue
 								case 'G': ++colour; // 010 Green
 								case 'C': ++colour; // 011 Cyan
@@ -1415,7 +1399,7 @@ GL3_RenderView(refdef_t *fd)
 	}
 #endif // 0 (stereo stuff)
 
-	if (gl_norefresh->value)
+	if (r_norefresh->value)
 	{
 		return;
 	}
@@ -1427,7 +1411,7 @@ GL3_RenderView(refdef_t *fd)
 		ri.Sys_Error(ERR_DROP, "R_RenderView: NULL worldmodel");
 	}
 
-	if (gl_speeds->value)
+	if (r_speeds->value)
 	{
 		c_brush_polys = 0;
 		c_alias_polys = 0;
@@ -1452,7 +1436,7 @@ GL3_RenderView(refdef_t *fd)
 
 	GL3_DrawEntitiesOnList();
 
-	// kick the silly gl_flashblend poly lights
+	// kick the silly gl1_flashblend poly lights
 	// GL3_RenderDlights();
 
 	GL3_DrawParticles();
@@ -1461,7 +1445,7 @@ GL3_RenderView(refdef_t *fd)
 
 	// Note: R_Flash() is now GL3_Draw_Flash() and called from GL3_RenderFrame()
 
-	if (gl_speeds->value)
+	if (r_speeds->value)
 	{
 		R_Printf(PRINT_ALL, "%4i wpoly %4i epoly %i tex %i lmaps\n",
 				c_brush_polys, c_alias_polys, c_visible_textures,
@@ -1525,22 +1509,22 @@ GL3_SetLightLevel(void)
 	{
 		if (shadelight[0] > shadelight[2])
 		{
-			gl_lightlevel->value = 150 * shadelight[0];
+			r_lightlevel->value = 150 * shadelight[0];
 		}
 		else
 		{
-			gl_lightlevel->value = 150 * shadelight[2];
+			r_lightlevel->value = 150 * shadelight[2];
 		}
 	}
 	else
 	{
 		if (shadelight[1] > shadelight[2])
 		{
-			gl_lightlevel->value = 150 * shadelight[1];
+			r_lightlevel->value = 150 * shadelight[1];
 		}
 		else
 		{
-			gl_lightlevel->value = 150 * shadelight[2];
+			r_lightlevel->value = 150 * shadelight[2];
 		}
 	}
 }
@@ -1575,7 +1559,7 @@ GL3_Clear(void)
 #endif // 0
 
 
-	if (gl_clear->value)
+	if (r_clear->value)
 	{
 		glClear(GL_COLOR_BUFFER_BIT | stencilFlags | GL_DEPTH_BUFFER_BIT);
 	}
@@ -1614,18 +1598,18 @@ void
 GL3_BeginFrame(float camera_separation)
 {
 	/* change modes if necessary */
-	if (gl_mode->modified)
+	if (r_mode->modified)
 	{
 		vid_fullscreen->modified = true;
 	}
 
 #if 0 // TODO: stereo stuff
 	gl_state.camera_separation = camera_separation;
-	// force a vid_restart if gl_stereo has been modified.
-	if ( gl_state.stereo_mode != gl_stereo->value ) {
+	// force a vid_restart if gl1_stereo has been modified.
+	if ( gl_state.stereo_mode != gl1_stereo->value ) {
 		// If we've gone from one mode to another with the same special buffer requirements there's no need to restart.
-		if ( GL_GetSpecialBufferModeForStereoMode( gl_state.stereo_mode ) == GL_GetSpecialBufferModeForStereoMode( gl_stereo->value )  ) {
-			gl_state.stereo_mode = gl_stereo->value;
+		if ( GL_GetSpecialBufferModeForStereoMode( gl_state.stereo_mode ) == GL_GetSpecialBufferModeForStereoMode( gl1_stereo->value )  ) {
+			gl_state.stereo_mode = gl1_stereo->value;
 		}
 		else
 		{
@@ -1654,7 +1638,7 @@ GL3_BeginFrame(float camera_separation)
 
 		if(gl3_overbrightbits->value < 0.0f)
 		{
-			ri.Cvar_Set("gl_overbrightbits", "0");
+			ri.Cvar_Set("gl3_overbrightbits", "0");
 		}
 
 		gl3state.uni3DData.overbrightbits = (gl3_overbrightbits->value <= 0.0f) ? 1.0f : gl3_overbrightbits->value;
@@ -1706,9 +1690,9 @@ GL3_BeginFrame(float camera_separation)
 		gl_anisotropic->modified = false;
 	}
 
-	if(gl_swapinterval->modified)
+	if(r_vsync->modified)
 	{
-		gl_swapinterval->modified = false;
+		r_vsync->modified = false;
 		GL3_SetSwapInterval();
 	}
 
