@@ -290,7 +290,7 @@ S_RegisterSound(char *name)
 {
 	sfx_t *sfx;
 
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return NULL;
 	}
@@ -310,8 +310,6 @@ struct sfx_s *
 S_RegisterSexedSound(entity_state_t *ent, char *base)
 {
 	int n;
-	char *p;
-	int len;
 	struct sfx_s *sfx;
 	char model[MAX_QPATH];
 	char sexedFilename[MAX_QPATH];
@@ -323,6 +321,7 @@ S_RegisterSexedSound(entity_state_t *ent, char *base)
 
 	if (cl.configstrings[n][0])
 	{
+		char *p;
 		p = strchr(cl.configstrings[n], '\\');
 
 		if (p)
@@ -351,6 +350,8 @@ S_RegisterSexedSound(entity_state_t *ent, char *base)
 
 	if (!sfx)
 	{
+		int len;
+
 		/* no, so see if it exists */
 		len = FS_LoadFile(&sexedFilename[1], NULL);
 
@@ -622,7 +623,7 @@ S_StartSound(vec3_t origin, int entnum, int entchannel, sfx_t *sfx,
 	sfxcache_t *sc;
 	playsound_t *ps, *sort;
 
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return;
 	}
@@ -671,12 +672,33 @@ S_StartSound(vec3_t origin, int entnum, int entchannel, sfx_t *sfx,
 
 	if (sfx->name[0])
 	{
+		vec3_t orientation, direction;
+		vec_t distance_direction;
+		int dir_x, dir_y, dir_z;
+
+		VectorSubtract(listener_forward, listener_up, orientation);
+
 		// with !fixed we have all sounds related directly to player,
 		// e.g. players fire, pain, menu
 		if (!ps->fixed_origin)
 		{
-			Haptic_Feedback(sfx->name);
+			VectorCopy(orientation, direction);
+			distance_direction = 0;
 		}
+		else
+		{
+			VectorSubtract(listener_origin, ps->origin, direction);
+			distance_direction = VectorLength(direction);
+		}
+
+		VectorNormalize(direction);
+		VectorNormalize(orientation);
+
+		dir_x = 16 * orientation[0] * direction[0];
+		dir_y = 16 * orientation[1] * direction[1];
+		dir_z = 16 * orientation[2] * direction[2];
+
+		Haptic_Feedback(sfx->name, 16 - distance_direction / 32, dir_x, dir_y, dir_z);
 	}
 
 	ps->entnum = entnum;
@@ -724,7 +746,7 @@ S_StartLocalSound(char *sound)
 {
 	sfx_t *sfx;
 
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return;
 	}
@@ -748,7 +770,7 @@ S_StopAllSounds(void)
 {
 	int i;
 
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return;
 	}
@@ -828,7 +850,7 @@ void
 S_RawSamples(int samples, int rate, int width,
 		int channels, byte *data, float volume)
 {
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return;
 	}
@@ -862,7 +884,7 @@ void
 S_Update(vec3_t origin, vec3_t forward, vec3_t right, vec3_t up)
 {
 
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return;
 	}
@@ -984,7 +1006,7 @@ S_SoundList(void)
 void
 S_SoundInfo_f(void)
 {
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		Com_Printf("Sound system not started\n");
 		return;
@@ -1037,10 +1059,6 @@ S_Init(void)
 	Cmd_AddCommand("stopsound", S_StopAllSounds);
 	Cmd_AddCommand("soundlist", S_SoundList);
 	Cmd_AddCommand("soundinfo", S_SoundInfo_f);
-#ifdef OGG
-	Cmd_AddCommand("ogg_init", OGG_Init);
-	Cmd_AddCommand("ogg_shutdown", OGG_Shutdown);
-#endif
 
 #if USE_OPENAL
 	cv = Cvar_Get("s_openal", "1", CVAR_ARCHIVE);
@@ -1086,7 +1104,7 @@ S_Shutdown(void)
 	int i;
 	sfx_t *sfx;
 
-	if (!sound_started)
+	if (sound_started == SS_NOT)
 	{
 		return;
 	}
@@ -1147,9 +1165,5 @@ S_Shutdown(void)
 	Cmd_RemoveCommand("soundinfo");
 	Cmd_RemoveCommand("play");
 	Cmd_RemoveCommand("stopsound");
-#ifdef OGG
-	Cmd_RemoveCommand("ogg_init");
-	Cmd_RemoveCommand("ogg_shutdown");
-#endif
 }
 
