@@ -32,7 +32,7 @@
 #include "shared.h"
 #include "crc.h"
 
-#define YQ2VERSION "7.10"
+#define YQ2VERSION "7.21"
 #define BASEDIRNAME "baseq2"
 
 #ifndef YQ2OSTYPE
@@ -53,16 +53,6 @@
  #define CFGDIR ".yq2"
 #endif
 
-#ifdef _WIN32
- #define LIBGL "opengl32.dll"
-#elif defined __OpenBSD__
- #define LIBGL "libGL.so"
-#elif defined __APPLE__
- #define LIBGL "/System/Library/Frameworks/OpenGL.framework/OpenGL"
-#else
- #define LIBGL "libGL.so.1"
-#endif
-
 /* ================================================================== */
 
 typedef struct sizebuf_s
@@ -531,7 +521,7 @@ qboolean NET_CompareAdr(netadr_t a, netadr_t b);
 qboolean NET_CompareBaseAdr(netadr_t a, netadr_t b);
 qboolean NET_IsLocalAddress(netadr_t adr);
 char *NET_AdrToString(netadr_t a);
-qboolean NET_StringToAdr(char *s, netadr_t *a);
+qboolean NET_StringToAdr(const char *s, netadr_t *a);
 void NET_Sleep(int msec);
 
 /*=================================================================== */
@@ -686,6 +676,7 @@ void FS_BuildGameSpecificSearchPath(char *dir);
 char *FS_Gamedir(void);
 char *FS_NextPath(char *prevpath);
 int FS_LoadFile(char *path, void **buffer);
+const char* FS_GetNextRawPath(const char* lastRawPath);
 
 /* a null buffer will just return the file length without loading */
 /* a -1 length is not present */
@@ -708,13 +699,13 @@ void FS_CreatePath(char *path);
 #define PRINT_ALL 0
 #define PRINT_DEVELOPER 1   /* only print when "developer 1" */
 
-void Com_BeginRedirect(int target, char *buffer, int buffersize, void (*flush));
+void Com_BeginRedirect(int target, char *buffer, int buffersize, void (*flush)(int, char *));
 void Com_EndRedirect(void);
 void Com_Printf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
 void Com_DPrintf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
 void Com_VPrintf(int print_level, const char *fmt, va_list argptr); /* print_level is PRINT_ALL or PRINT_DEVELOPER */
-void Com_MDPrintf(char *fmt, ...);
-void Com_Error(int code, char *fmt, ...);
+void Com_MDPrintf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+void Com_Error(int code, char *fmt, ...) __attribute__ ((format (printf, 2, 3)));
 void Com_Quit(void);
 
 int Com_ServerState(void);              /* this should have just been a cvar... */
@@ -732,6 +723,12 @@ extern cvar_t *log_stats;
 /* Hack for portable client */
 extern qboolean is_portable;
 
+/* Hack fo external datadir */
+extern char datadir[MAX_OSPATH];
+
+/* Hack for working 'game' cmd */
+extern char userGivenGame[MAX_QPATH];
+
 extern FILE *log_stats_file;
 
 /* host_speeds times */
@@ -746,6 +743,8 @@ void *Z_TagMalloc(int size, int tag);
 void Z_FreeTags(int tag);
 
 void Qcommon_Init(int argc, char **argv);
+void Qcommon_ExecConfigs(qboolean addEarlyCmds);
+const char* Qcommon_GetInitialGame(void);
 void Qcommon_Frame(int msec);
 void Qcommon_Shutdown(void);
 
@@ -755,26 +754,6 @@ extern vec3_t bytedirs[NUMVERTEXNORMALS];
 /* this is in the client code, but can be used for debugging from server */
 void SCR_DebugGraph(float value, int color);
 
-/* NON-PORTABLE OSTYPE SERVICES */
-
-void Sys_Init(void);
-void Sys_UnloadGame(void);
-void *Sys_GetGameAPI(void *parms);
-
-char *Sys_ConsoleInput(void);
-void Sys_ConsoleOutput(char *string);
-void Sys_SendKeyEvents(void);
-void Sys_Error(char *error, ...);
-void Sys_Quit(void);
-char *Sys_GetHomeDir(void);
-const char *Sys_GetBinaryDir(void);
-long long Sys_Microseconds(void);
-void Sys_FreeLibrary(void *handle);
-void *Sys_LoadLibrary(const char *path, const char *sym, void **handle);
-void *Sys_GetProcAddress(void *handle, const char *sym);
-void Sys_RedirectStdout(void);
-void Sys_SetupFPU(void);
-
 /* CLIENT / SERVER SYSTEMS */
 
 void CL_Init(void);
@@ -788,4 +767,37 @@ void SV_Init(void);
 void SV_Shutdown(char *finalmsg, qboolean reconnect);
 void SV_Frame(int msec);
 
+/* ======================================================================= */
+
+// Platform specific functions.
+
+// system.c
+char *Sys_ConsoleInput(void);
+void Sys_ConsoleOutput(char *string);
+void Sys_Error(char *error, ...);
+void Sys_Quit(void);
+void Sys_Init(void);
+char *Sys_GetHomeDir(void);
+long long Sys_Microseconds(void);
+void Sys_Nanosleep(int);
+void *Sys_GetProcAddress(void *handle, const char *sym);
+void Sys_FreeLibrary(void *handle);
+void *Sys_LoadLibrary(const char *path, const char *sym, void **handle);
+void *Sys_GetGameAPI(void *parms);
+void Sys_UnloadGame(void);
+void Sys_GetWorkDir(char *buffer, size_t len);
+qboolean Sys_SetWorkDir(char *path);
+
+// Windows only (system.c)
+#ifdef _WIN32
+void Sys_RedirectStdout(void);
+void Sys_SetHighDPIMode(void);
+#endif
+
+// misc.c
+const char *Sys_GetBinaryDir(void);
+void Sys_SetupFPU(void);
+
+/* ======================================================================= */
+
 #endif
